@@ -77,7 +77,7 @@ setMethod("RobMxtDEst",
     if (Mxt=="Hom" && CovEstMet=="Globdev")
     {
 #      X <- cbind(Idt@MidP,Idt@LogR)
-      X <- cbind.data.frame(Idt@MidP,Idt@LogR)
+      X <- cbind(Idt@MidP,Idt@LogR)
       Xdev <- matrix(nrow=n,ncol=p) 
       Xgl1med <- matrix(nrow=ngrps,ncol=p) 
       if (!is.null(l1medpar)) {
@@ -125,8 +125,7 @@ setMethod("RobMxtDEst",
                 CovConfC[[CovC]]$RobSigE + (ng[g]/n) * grpRobE[[g]]@CovConfCases[[CovC]]$RobSigE 
             }
             regset <- ifelse(reweighted,grpRobE[[g]]@RewghtdSet,grpRobE[[g]]@rawSet)
-#            X <- rbind(X,cbind(Idtg@MidP[regset,],Idtg@LogR[regset,]))
-            X <- rbind.data.frame(X,cbind.data.frame(Idtg@MidP[regset,],Idtg@LogR[regset,]))
+            X <- rbind(X,cbind(Idtg@MidP[regset,],Idtg@LogR[regset,]))
           }
           else if (CovEstMet=="Globdev") {
             if  (getkdblstar=="Twopplusone") { 
@@ -144,8 +143,7 @@ setMethod("RobMxtDEst",
           }
           Xdev <- scale(X[grouping==levels(grouping)[1],],center=RobNmuE[1,],scale=FALSE)
           for (g in 2:ngrps)
-#            Xdev <- rbind(Xdev,scale(X[grouping==levels(grouping)[g],],center=RobNmuE[g,],scale=FALSE))
-            Xdev <- rbind.data.frame(Xdev,scale(X[grouping==levels(grouping)[g],],center=RobNmuE[g,],scale=FALSE))
+            Xdev <- rbind(Xdev,scale(X[grouping==levels(grouping)[g],],center=RobNmuE[g,],scale=FALSE))
           logdet <- pdwt.solve(CovConfC[[CovC]]$RobSigE,silent=TRUE,onlylogdet=TRUE)
           if (is.null(logdet))  {
             logLiks[CovC] <- CovConfC[[CovC]]$logLik <- -Inf
@@ -199,8 +197,7 @@ setMethod("RobMxtDEst",
 
       if(getalpha=="TwoStep" && Steps==1)
       {
-#        X <- data.frame(cbind(Idt@MidP,Idt@LogR))
-        X <- data.frame(cbind.data.frame(Idt@MidP,Idt@LogR))
+        X <- data.frame(cbind(Idt@MidP,Idt@LogR))
         nOtls <- 0.
         for (g in 1:ngrps)
         {
