@@ -1,5 +1,6 @@
 #include "tle.h"
 #include "msnCP_dev.h"
+#include "msnCP_dev_grad.h"
 #include "CEMGauss.h"
 
 #include <R.h>
@@ -8,15 +9,14 @@
 #include <R_ext/Rdynload.h>
 
 static const R_CallMethodDef CallEntries[] = {
-//  {"Cfasttle",       (DL_FUNC) &Cfasttle,       12},
-//  {"Cfulltle",       (DL_FUNC) &Cfulltle,        6},
-//  {"msnCP_dev",      (DL_FUNC) &msnCP_dev,      14},
-//  {"msnCP_dev_grad", (DL_FUNC) &msnCP_dev_grad, 13},
   {"Cfasttle",       (DL_FUNC) &Cfasttle,       13},
   {"Cfulltle",       (DL_FUNC) &Cfulltle,        7},
-  {"msnCP_dev",      (DL_FUNC) &msnCP_dev,      15},
-  {"msnCP_dev_grad", (DL_FUNC) &msnCP_dev_grad, 15},
+//  {"msnCP_dev",      (DL_FUNC) &msnCP_dev,      15},
+//  {"msnCP_dev_grad", (DL_FUNC) &msnCP_dev_grad, 15},
+  {"msnCP_dev",      (DL_FUNC) &msnCP_dev,      16},
+  {"msnCP_dev_grad", (DL_FUNC) &msnCP_dev_grad, 16},
   {"CEMGauss",       (DL_FUNC) &CEMGauss,       18},
+
   {NULL, NULL, 0}
 };
 
